<?php
/**
 * This is where the magic begins.
*/

defined( 'ABSPATH' ) || exit;

final class WPEX_Theme_Setup {

	/**
	 * Our single WPEX_Theme_Setup instance.
	 */
	private static $instance;

	/**
	 * Disable instantiation.
	 */
	private function __construct() {}

	/**
	 * Disable the cloning of this class.
	 *
	 * @return void
	 */
	final public function __clone() {}

	/**
	 * Disable the wakeup of this class.
	 */
	final public function __wakeup() {}

	/**
	 * Create or retrieve the instance of WPEX_Theme_Setup.
	 */
	public static function instance() {
		if ( is_null( static::$instance ) ) {
			static::$instance = new WPEX_Theme_Setup;
			static::$instance->define_constants();
			static::$instance->register_autoloader();
			static::$instance->initialize();
			static::$instance->init_hooks();
		}

		return static::$instance;
	}

	/**
	 * Define constants.
	 */
	public function define_constants() {

		// TotalTheme version.
		define( 'TOTAL_THEME_ACTIVE', true );
		define( 'WPEX_THEME_VERSION', '5.1.2' );

		// Supported Bundled plugin versions.
		define( 'WPEX_VC_SUPPORTED_VERSION', '6.6.0' );
		define( 'WPEX_THEME_CORE_PLUGIN_SUPPORTED_VERSION', '1.2.10' );

		// Theme Branding.
		define( 'WPEX_THEME_BRANDING', get_theme_mod( 'theme_branding', 'Travelport' ) );

		// Theme changelog URL.
		define( 'WPEX_THEME_CHANGELOG_URL', 'https://go6.media/' );

		// Theme directory location and URL.
		define( 'WPEX_THEME_DIR', get_template_directory() );
		define( 'WPEX_THEME_URI', get_template_directory_uri() );

		// Theme Panel slug and hook prefix.
		define( 'WPEX_THEME_PANEL_SLUG', 'wpex-panel' );
		define( 'WPEX_ADMIN_PANEL_HOOK_PREFIX', 'theme-panel_page_' . WPEX_THEME_PANEL_SLUG );

		// Includes folder.
		define( 'WPEX_INC_DIR', trailingslashit( WPEX_THEME_DIR ) . 'inc/' );

		// Theme stylesheet and main javascript handles.
		define( 'WPEX_THEME_STYLE_HANDLE', 'wpex-style' );
		define( 'WPEX_THEME_JS_HANDLE', 'wpex-core' ); //@todo rename to wpex-js?

		// Check if certain plugins are enabled.
		define( 'WPEX_PTU_ACTIVE', class_exists( 'Post_Types_Unlimited' ) );
		define( 'WPEX_VC_ACTIVE', class_exists( 'Vc_Manager' ) );
		define( 'WPEX_TEMPLATERA_ACTIVE', class_exists( 'VcTemplateManager' ) );
		define( 'WPEX_WOOCOMMERCE_ACTIVE', class_exists( 'WooCommerce' ) );
		define( 'WPEX_WPML_ACTIVE', class_exists( 'SitePress' ) );
		define( 'WPEX_ELEMENTOR_ACTIVE', did_action( 'elementor/loaded' ) );
		define( 'WPEX_BBPRESS_ACTIVE', class_exists( 'bbPress' ) );

		// Theme Core post type checks.
		define( 'WPEX_PORTFOLIO_IS_ACTIVE', get_theme_mod( 'portfolio_enable', false ) );
		define( 'WPEX_STAFF_IS_ACTIVE', get_theme_mod( 'staff_enable', false ) );
		define( 'WPEX_TESTIMONIALS_IS_ACTIVE', get_theme_mod( 'testimonials_enable', false ) );

	}

	/**
	 * Autoloader.
	 */
	public function register_autoloader() {
		require_once trailingslashit( WPEX_THEME_DIR ) . 'inc/autoloader.php';
		TotalTheme\Autoloader::run();
	}

	/**
	 * Initialize the theme by including files and initializing classes.
	 */
	public function initialize() {
		$this->global_functionality();
		$this->admin_functionality();
		$this->public_functionality();
	}

	/**
	 * Global functionality.
	 */
	public function global_functionality() {

		/*** Always include ***/

		// Core.
		require_once WPEX_INC_DIR . 'updates/after-update.php';
		require_once WPEX_INC_DIR . 'functions/deprecated.php';
		require_once WPEX_INC_DIR . 'functions/theme-mods.php';
		require_once WPEX_INC_DIR . 'functions/core-functions.php';
		require_once WPEX_INC_DIR . 'functions/conditionals.php';
		require_once WPEX_INC_DIR . 'functions/svgs.php';
		require_once WPEX_INC_DIR . 'functions/css-utility.php';
		require_once WPEX_INC_DIR . 'functions/parsers.php';
		require_once WPEX_INC_DIR . 'functions/sanitization-functions.php';
		require_once WPEX_INC_DIR . 'functions/arrays.php';
		require_once WPEX_INC_DIR . 'functions/translations.php';
		require_once WPEX_INC_DIR . 'functions/template-parts.php';
		require_once WPEX_INC_DIR . 'functions/wp-fallbacks.php';
		require_once WPEX_INC_DIR . 'functions/post-types-branding.php';
		require_once WPEX_INC_DIR . 'functions/recommended-plugins.php';
		require_once WPEX_INC_DIR . 'functions/fonts.php';
		require_once WPEX_INC_DIR . 'functions/theme-icons.php';
		require_once WPEX_INC_DIR . 'functions/post-thumbnails.php';
		require_once WPEX_INC_DIR . 'functions/overlays.php';
		require_once WPEX_INC_DIR . 'functions/shape-dividers.php';
		require_once WPEX_INC_DIR . 'functions/blocks-single.php';
		require_once WPEX_INC_DIR . 'functions/blocks-entry.php';
		require_once WPEX_INC_DIR . 'functions/blocks-meta.php';
		require_once WPEX_INC_DIR . 'functions/aria-labels.php';
		require_once WPEX_INC_DIR . 'cards/card-functions.php';

		// Actions and filters.
		require_once WPEX_INC_DIR . 'functions/wp-actions/after-switch-theme.php';
		require_once WPEX_INC_DIR . 'functions/wp-actions/register-widget-areas.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/disable-wp-update-check.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/honor-ssl-for-attachements.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/allowed-kses-protocols.php';

		// Theme builder.
		require_once WPEX_INC_DIR . 'theme-builder/functions/theme-builder-functions.php'; // most load here.
		require_once WPEX_INC_DIR . 'theme-builder/theme-builder.php';

		/** Maybe include */

		// Header builder.
		if ( get_theme_mod( 'header_builder_enable', true ) ) {
			require_once WPEX_INC_DIR . 'theme-builder/header-builder.php';
		}

		// Footer builder.
		if ( get_theme_mod( 'footer_builder_enable', true ) ) {
			require_once WPEX_INC_DIR . 'theme-builder/footer-builder.php';
		}

		// Custom 404 Page.
		if ( get_theme_mod( 'custom_404_enable', true ) ) {
			require_once WPEX_INC_DIR . 'theme-builder/custom-404.php';
		}

		// Page animations.
		if ( get_theme_mod( 'page_animations_enable', true ) ) {
			TotalTheme\Page_Animations::instance();
		}

		// WP Header Image support.
		if ( get_theme_mod( 'header_image_enable', false ) ) {
			TotalTheme\WP_Custom_Header::instance();
		}

		// Custom accent colors.
		if ( get_theme_mod( 'accent_colors_enable', true ) ) {
			TotalTheme\Accent_Colors::instance();
		}

		// Custom border colors.
		if ( get_theme_mod( 'border_colors_enable', true ) ) {
			TotalTheme\Border_Colors::instance();
		}

		// Custom output for WP gallery.
		if ( wpex_custom_wp_gallery_supported() ) {
			TotalTheme\Post_Gallery::instance();
		}

		// Under Construction.
		if ( get_theme_mod( 'under_construction_enable', true ) ) {
			TotalTheme\Under_Construction::instance();
		}

		// Helper class for disabling Google services.
		if ( wpex_disable_google_services() ) {
			TotalTheme\Disable_Google_Services::instance();
		}

		// Custom Favicons panel and output.
		if ( get_theme_mod( 'favicons_enable', true ) ) {
			TotalTheme\Favicons::instance();
		}

		// Custom login page.
		if ( get_theme_mod( 'custom_admin_login_enable', true ) ) {
			TotalTheme\Custom_Login::instance();
		}

		// Custom actions panel.
		if ( get_theme_mod( 'custom_actions_enable', true ) ) {
			TotalTheme\Custom_Actions::instance();
		}

		// Helper class for removing cpt slugs.
		if ( get_theme_mod( 'remove_posttype_slugs', false ) ) {
			TotalTheme\Remove_Cpt_Slugs::instance();
		}

		/** Plugin/Vendor Support **/

		// WPBakery integration.
		if ( WPEX_VC_ACTIVE && wpex_has_vc_mods() ) {
			TotalTheme\Integration\WPBakery::instance();
		}

		// WooCommerce integration.
		if ( WPEX_WOOCOMMERCE_ACTIVE ) {
			if ( wpex_has_woo_mods() && wpex_woo_version_supported() ) {
				TotalTheme\Integration\WooCommerce\WooCommerce_Advanced::instance();
			} else {
				TotalTheme\Integration\WooCommerce\WooCommerce_Vanilla::instance();
			}
		}

		// Elementor integration.
		if ( WPEX_ELEMENTOR_ACTIVE && apply_filters( 'wpex_elementor_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-elementor.php';
		}

		// Post Types Unlimited integration.
		if ( WPEX_PTU_ACTIVE ) {
			TotalTheme\Integration\Post_Types_Unlimited::instance();
		}

		// Yoast SEO integration.
		if ( defined( 'WPSEO_VERSION' ) && apply_filters( 'wpex_yoastseo_support', true ) ) {
			TotalTheme\Integration\Yoast_SEO::instance();
		}

		// The Events Calendar integration.
		if ( class_exists( 'Tribe__Events__Main' ) && apply_filters( 'wpex_tribe_events_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/tribe-events/class-tribe-events.php';
		}

		// One-Click Demo importer integration.
		if ( class_exists( 'OCDI\OneClickDemoImport' ) && apply_filters( 'wpex_ocdi_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-ocdi.php';
		}

		// W3 Total cache integration.
		if ( defined( 'W3TC' ) && apply_filters( 'wpex_w3_total_cache_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-w3-total-cache.php';
		}

		// Real Media library integration.
		if ( defined( 'RML_VERSION' ) && apply_filters( 'wpex_realmedialibrary_support', true ) ) {
			new TotalTheme\Integration\Real_Media_Library();
		}

		// WPML integration.
		if ( WPEX_WPML_ACTIVE && apply_filters( 'wpex_wpml_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-wpml.php';
		}

		// Polylang integration.
		if ( class_exists( 'Polylang' ) && apply_filters( 'wpex_polylang_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-polylang.php';
		}

		// bbPress integration.
		if ( WPEX_BBPRESS_ACTIVE && apply_filters( 'wpex_bbpress_support', true ) ) {
			TotalTheme\Integration\bbPress::instance();
		}

		// BuddyPress integration.
		if ( function_exists( 'buddypress' ) && apply_filters( 'wpex_buddypress_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-buddy-press.php';
		}

		// Contact form 7 integration.
		if ( defined( 'WPCF7_VERSION' ) && apply_filters( 'wpex_contactform7_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-contact-form-7.php';
		}

		// Gravity form integration.
		if ( class_exists( 'RGForms' ) && apply_filters( 'wpex_gravityforms_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-gravity-forms.php';
		}

		// JetPack integration.
		if ( class_exists( 'Jetpack' ) && apply_filters( 'wpex_jetpack_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-jetpack.php';
		}

		// Learndash integration.
		if ( defined( 'LEARNDASH_VERSION' ) && apply_filters( 'wpex_learndash_support', true ) ) {
			TotalTheme\Integration\Learn_Dash::instance();
		}

		// Sensei plugin integration.
		if ( function_exists( 'Sensei' ) && apply_filters( 'wpex_sensei_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-sensei.php';
		}

		// Custom Post Type UI integration.
		if ( function_exists( 'cptui_init' ) && apply_filters( 'wpex_cptui_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-custom-post-type-ui.php';
		}

		// Massive Addons for WPBakery integration.
		if ( defined( 'MPC_MASSIVE_VERSION' ) && apply_filters( 'wpex_massive_addons_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-massive-addons.php';
		}

		// TablePress integration.
		if ( class_exists( 'TablePress' ) && apply_filters( 'wpex_tablepress_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-table-press.php';
		}

		// Slider Revolution integration.
		if ( class_exists( 'RevSlider' ) && apply_filters( 'wpex_revslider_support', true ) ) {
			require_once WPEX_INC_DIR . 'plugins/class-revslider.php';
		}

		/* These Classes must Load last */

		// Image sizes panel and registration.
		if ( get_theme_mod( 'image_sizes_enable', true ) ) {
			TotalTheme\Image_Sizes::instance();
		}

		// Customizer utility class and theme settings array.
		require_once WPEX_INC_DIR . 'customizer/class-wpex-customizer.php';

		// Typography Customizer panel, settings and front-end output.
		if ( get_theme_mod( 'typography_enable', true ) ) {
			new TotalTheme\Typography();
		}

	}

	/**
	 * Admin functionality.
	 */
	public function admin_functionality() {

		// Main Theme Panel.
		TotalTheme\Admin\Theme_Panel::instance();

		// Provide auto updates for the theme.
		// if ( get_theme_mod( 'auto_updates', false ) ) {
		// 	TotalTheme\Updates\Theme_Updater::instance();
		// }

		// Plugin update notifications.
		// if ( apply_filters( 'wpex_has_bundled_plugin_update_notices', true ) ) {
		// 	TotalTheme\Updates\Plugin_Updater::instance();
		// }

		// Post type editor class.
		if ( get_theme_mod( 'post_type_admin_settings', true ) ) {
			TotalTheme\Admin\Cpt_Settings::instance();
		}

		// Import/Export panel.
		if ( get_theme_mod( 'import_export_enable', true ) ) {
			TotalTheme\Admin\Import_Export::instance();
		}

		// Theme license panel.
		// if ( apply_filters( 'wpex_show_license_panel', true ) ) {
		// 	TotalTheme\Admin\License_Panel::instance();
		// }

		// Mce format styles.
		TotalTheme\Editor\Mce_Formats::instance();

		// Accessibility Panel.
		if ( apply_filters( 'wpex_accessibility_panel', true ) ) {
			TotalTheme\Accessibility\Admin_Panel::instance();
		}

		// Custom styles for the WP editor (classic & gutenberg).
		if ( get_theme_mod( 'editor_styles_enable', true ) ) {
			TotalTheme\Editor\Editor_Styles::instance();
		}

		// Display Thumbnails in the WP admin posts list view.
		TotalTheme\Admin\Dashboard_Thumbnails::instance();

		// Register & Enqueue scripts for use in the admin.
		TotalTheme\Admin\Scripts::instance();

	}

	/**
	 * Public/Frontend functionality.
	 */
	public function public_functionality() {

		// Core functions.
		require_once WPEX_INC_DIR . 'functions/frontend/google-analytics.php';
		require_once WPEX_INC_DIR . 'functions/frontend/aria-landmark.php';
		require_once WPEX_INC_DIR . 'functions/frontend/layouts.php';
		require_once WPEX_INC_DIR . 'functions/frontend/breadcrumbs.php';
		require_once WPEX_INC_DIR . 'functions/frontend/wpex-the-content.php';
		require_once WPEX_INC_DIR . 'functions/frontend/js-localize-data.php';
		require_once WPEX_INC_DIR . 'functions/frontend/head-meta-tags.php';
		require_once WPEX_INC_DIR . 'functions/frontend/schema-markup.php';
		require_once WPEX_INC_DIR . 'functions/frontend/social-share.php';
		require_once WPEX_INC_DIR . 'functions/frontend/videos.php';
		require_once WPEX_INC_DIR . 'functions/frontend/audio.php';
		require_once WPEX_INC_DIR . 'functions/frontend/author.php';
		require_once WPEX_INC_DIR . 'functions/frontend/post-media.php';
		require_once WPEX_INC_DIR . 'functions/frontend/excerpts.php';
		require_once WPEX_INC_DIR . 'functions/frontend/togglebar.php';
		require_once WPEX_INC_DIR . 'functions/frontend/topbar.php';
		require_once WPEX_INC_DIR . 'functions/frontend/header.php';
		require_once WPEX_INC_DIR . 'functions/frontend/header-menu.php';
		require_once WPEX_INC_DIR . 'functions/frontend/title.php';
		require_once WPEX_INC_DIR . 'functions/frontend/post-slider.php';
		require_once WPEX_INC_DIR . 'functions/frontend/post-gallery.php';
		require_once WPEX_INC_DIR . 'functions/frontend/page-header.php';
		require_once WPEX_INC_DIR . 'functions/frontend/sidebar.php';
		require_once WPEX_INC_DIR . 'functions/frontend/footer-callout.php';
		require_once WPEX_INC_DIR . 'functions/frontend/footer.php';
		require_once WPEX_INC_DIR . 'functions/frontend/footer-bottom.php';
		require_once WPEX_INC_DIR . 'functions/frontend/pagination.php';
		require_once WPEX_INC_DIR . 'functions/frontend/grids.php';
		require_once WPEX_INC_DIR . 'functions/frontend/page.php';
		require_once WPEX_INC_DIR . 'functions/frontend/archives.php';
		require_once WPEX_INC_DIR . 'functions/frontend/loop.php';
		require_once WPEX_INC_DIR . 'functions/frontend/blog.php';
		require_once WPEX_INC_DIR . 'functions/frontend/portfolio.php';
		require_once WPEX_INC_DIR . 'functions/frontend/staff.php';
		require_once WPEX_INC_DIR . 'functions/frontend/testimonials.php';
		require_once WPEX_INC_DIR . 'functions/frontend/cpt.php';
		require_once WPEX_INC_DIR . 'functions/frontend/search.php';
		require_once WPEX_INC_DIR . 'functions/frontend/star-rating.php';
		require_once WPEX_INC_DIR . 'functions/frontend/user-social-links.php';
		require_once WPEX_INC_DIR . 'functions/frontend/post-format-icons.php';
		require_once WPEX_INC_DIR . 'functions/frontend/local-scroll.php';

		// Actions and filters.
		require_once WPEX_INC_DIR . 'functions/wp-actions/redirections.php';
		require_once WPEX_INC_DIR . 'functions/wp-actions/pre-get-posts.php';
		require_once WPEX_INC_DIR . 'functions/wp-actions/wp-enqueue-scripts.php';

		require_once WPEX_INC_DIR . 'functions/wp-filters/body-class.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/post-class.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/oembed.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/singular-pagination-fix.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/move-comment-form-fields.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/schema-author-posts-link.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/comments-link-scrollto-fix.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/next-previous-posts-exclude.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/custom-password-protection-form.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/widget-tag-cloud-args.php';
		require_once WPEX_INC_DIR . 'functions/wp-filters/widget-custom-classes.php';

		// Remove menu ID's for accessibility if enabled.
		if ( get_theme_mod( 'remove_menu_ids', false ) && apply_filters( 'wpex_accessibility_panel', true ) ) {
			require_once WPEX_INC_DIR . 'functions/wp-filters/accessibility-remove-menu-ids.php';
		}

		// Remove site emoji scripts.
		if ( get_theme_mod( 'remove_emoji_scripts_enable', true ) ) {
			require_once WPEX_INC_DIR . 'functions/wp-actions/remove-emoji-scripts.php';
		}

		// Add a span around the WordPress category widgets for easier styling.
		if ( apply_filters( 'wpex_widget_counter_span', true ) ) {
			require_once WPEX_INC_DIR . 'functions/wp-filters/widget-add-span-to-count.php';
		}

		// Enable post thumbnail format icons.
		if ( get_theme_mod( 'thumbnail_format_icons', false ) ) {
			TotalTheme\Thumbnail_Format_Icons::instance();
		}

		// Load global fonts.
		TotalTheme\Fonts\Global_Fonts::instance();

		// Custom site backgrounds.
		TotalTheme\Site_Backgrounds::instance();

		// Theme breadcrumbs.
		require_once WPEX_INC_DIR . 'lib/wpex-breadcrumbs.php';

		// Outputs inline CSS for theme settings.
		new TotalTheme\Inline_CSS();

		// Preload assets.
		TotalTheme\Preload_Assets::instance();

		/*** Maybe include ***/

			// Advanced styles for various Customizer options.
			if ( apply_filters( 'wpex_generate_advanced_styles', true ) ) {
				TotalTheme\Advanced_Styles::instance();
			}

	}

	/**
	 * Hook into actions and filters.
	 */
	public function init_hooks() {
		TotalTheme\Setup::instance();
		add_action( 'after_setup_theme', array( $this, 'hooks_actions' ), 10 );
		add_filter( 'woocommerce_create_pages', array( $this, 'woocommerce_create_pages' ) );
	}

	/**
	 * Defines all theme hooks and runs all needed actions for theme hooks.
	 */
	public function hooks_actions() {

		// Register theme hooks (needed in backend for actions panel).
		require_once WPEX_INC_DIR . 'functions/hooks/hooks.php';

		// Add default theme actions.
		require_once WPEX_INC_DIR . 'functions/hooks/add-actions.php';

		// Remove actions and helper functions to remove all theme actions.
		require_once WPEX_INC_DIR . 'functions/hooks/remove-actions.php';

		// Functions used to return correct partial/template-parts.
		require_once WPEX_INC_DIR . 'functions/hooks/partials.php';

	}

	/**
	 * Prevent Woocommerce from installing pages on installation.
	 */
	public function woocommerce_create_pages( $pages ) {

		if ( defined( 'WC_INSTALLING' ) && true === WC_INSTALLING ) {
			return array();

		}

		return $pages;

	}

}
WPEX_Theme_Setup::instance();

function my_custom_header_text() { ?>
	<p class="wpex-inline wpex-pl-10 wpex-align-middle" style="color:#544d45">|<span class="wpex-pl-10" style="color:#f7e4cb">Official Partner</span></p>
	<?php }
	add_action( 'wpex_hook_site_logo_inner', 'my_custom_header_text', 999 );

	function ra_change_translate_text_multiple( $translated ) {
		$text = array(
			'WPBakery Page Builder' => 'Page Builder',
		);
		$translated = str_ireplace(  array_keys($text),  $text,  $translated );
		return $translated;
	}
	add_filter( 'gettext', 'ra_change_translate_text_multiple', 20 );