<?php
namespace TotalTheme\Integration\WPBakery;

defined( 'ABSPATH' ) || exit;

final class Add_Params {

	/**
	 * Our single Add_Params instance.
	 */
	private static $instance;

	/**
	 * Disable instantiation.
	 */
	private function __construct() {}

	/**
	 * Disable the cloning of this class.
	 *
	 * @return void
	 */
	final public function __clone() {}

	/**
	 * Disable the wakeup of this class.
	 */
	final public function __wakeup() {}

	/**
	 * Create or retrieve the instance of Add_Params.
	 */
	public static function instance() {
		if ( is_null( static::$instance ) ) {
			static::$instance = new Add_Params;
			static::$instance->init_hooks();
		}

		return static::$instance;
	}

	/**
	 * Get things started.
	 */
	public function init_hooks() {

		// Doesn't need init hook because we are modifying VC modules only.
		// MUCH slower hooking into INIT.
		add_action( 'vc_after_init', array( $this, 'add_params' ), 40 );

	}

	/**
	 * Return array of params to add.
	 */
	public function get_params() {
		return (array) apply_filters( 'wpex_vc_add_params', array() );
	}

	/**
	 * Hook into wpex_head_css to add inline CSS for WPBakery.
	 *
	 * @todo update to use vc_map_update?
	 *
	 * vc_map_update($shortcode, $newData); make sure to unset($newData['base']) to avoid warning.
	 * $getAllShortCodes = WPBMap::getAllShortCodes();
	 */
	public function add_params() {

		if ( ! function_exists( 'vc_add_param' ) ) {
			return;
		}

		$params = $this->get_params();

		if ( ! $params ) {
			return;
		}

		foreach ( $params as $module => $params ) {

			if ( is_array( $params ) ) {

				foreach ( $params as $param ) {

					vc_add_param( $module, $param );

				}

			}

		}

	}

}