<?php
namespace TotalTheme\Integration\WPBakery;

defined( 'ABSPATH' ) || exit;

final class Disable_Design_Options {

	/**
	 * Our single Disable_Design_Options instance.
	 */
	private static $instance;

	/**
	 * Disable instantiation.
	 */
	private function __construct() {}

	/**
	 * Disable the cloning of this class.
	 *
	 * @return void
	 */
	final public function __clone() {}

	/**
	 * Disable the wakeup of this class.
	 */
	final public function __wakeup() {}

	/**
	 * Create or retrieve the instance of Disable_Design_Options.
	 */
	public static function instance() {
		if ( is_null( static::$instance ) ) {
			static::$instance = new Disable_Design_Options;
			static::$instance->init_hooks();
		}

		return static::$instance;
	}

	/**
	 * Get things started.
	 */
	public function init_hooks() {

		if ( get_option( 'wpb_js_use_custom' ) ) {
			delete_option( 'wpb_js_use_custom' );
		}

		add_filter( 'vc_settings_page_show_design_tabs', '__return_false' );
		add_action( 'wp_enqueue_scripts', array( $this, 'dequeue_scripts' ) );

	}

	/**
	 * Dequeue scripts.
	 */
	public function dequeue_scripts() {
		wp_deregister_style( 'js_composer_custom_css' );
	}

}