<?php
namespace TotalTheme\Integration\WPBakery;

defined( 'ABSPATH' ) || exit;

final class Disable_Template_Library {

	/**
	 * Our single Disable_Template_Library instance.
	 */
	private static $instance;

	/**
	 * Disable instantiation.
	 */
	private function __construct() {}

	/**
	 * Disable the cloning of this class.
	 *
	 * @return void
	 */
	final public function __clone() {}

	/**
	 * Disable the wakeup of this class.
	 */
	final public function __wakeup() {}

	/**
	 * Create or retrieve the instance of Disable_Template_Library.
	 */
	public static function instance() {
		if ( is_null( static::$instance ) ) {
			static::$instance = new Disable_Template_Library;
			static::$instance->init_hooks();
		}

		return static::$instance;
	}

	/**
	 * Get things started.
	 */
	public function init_hooks() {

		if ( is_admin() ) {
			add_filter( 'vc_get_all_templates', array( $this, 'remove_templates' ), 99 );
		}

	}

	/**
	 * Remove templates.
	 */
	public function remove_templates( $data ) {
		if ( $data && is_array( $data ) ) {
			foreach( $data as $key => $val ) {
				if ( isset( $val['category'] ) && 'shared_templates' === $val['category'] ) {
					unset( $data[$key] );
				}
			}
		}
		return $data;
	}

}