<?php
namespace TotalTheme\Integration\WPBakery;
use \WPBMap;

defined( 'ABSPATH' ) || exit;

final class Modify_Params {

	/**
	 * Our single Modify_Params instance.
	 */
	private static $instance;

	/**
	 * Disable instantiation.
	 */
	private function __construct() {}

	/**
	 * Disable the cloning of this class.
	 *
	 * @return void
	 */
	final public function __clone() {}

	/**
	 * Disable the wakeup of this class.
	 */
	final public function __wakeup() {}

	/**
	 * Create or retrieve the instance of Modify_Params.
	 */
	public static function instance() {
		if ( is_null( static::$instance ) ) {
			static::$instance = new Modify_Params;
			static::$instance->init_hooks();
		}

		return static::$instance;
	}

	/**
	 * Get things started.
	 */
	public function init_hooks() {

		// Doesn't need init hook because we are modifying VC modules only.
		// MUCH slower hooking into INIT.
		add_action( 'vc_after_init', array( $this, 'modify_params' ), 40 );

	}

	/**
	 * Return array of params to modify.
	 */
	public function get_params() {
		return (array) apply_filters( 'wpex_vc_modify_params', array() );
	}

	/**
	 * Hook into wpex_head_css to add inline CSS for WPBakery.
	 *
	 * @todo update to use vc_map_update?
	 *
	 * vc_map_update($shortcode, $newData); make sure to unset($newData['base']) to avoid warning.
	 * $getAllShortCodes = WPBMap::getAllShortCodes();
	 */
	public function modify_params() {

		if ( ! function_exists( 'vc_update_shortcode_param' ) ) {
			return;
		}

		$params = $this->get_params();

		if ( ! $params ) {
			return;
		}

		foreach ( $params as $module => $params ) {

			foreach ( $params as $param_id => $settings ) {

				if ( is_array( $settings ) ) {

					foreach ( $settings as $key => $value ) {

						$get_param = WPBMap::getParam( $module, $param_id );

						if ( $get_param && is_array( $get_param ) ) {

							if ( is_array( $value ) ) {
								if ( 'dependency' == $key ) {
									$get_param[$key] = $value;
								} else {
									foreach ( $value as $sub_k => $sub_v ) {
										$get_param[$key][$sub_k] = $sub_v;
									}
								}
							} else {
								$get_param[$key] = $value;
							}

							vc_update_shortcode_param( $module, $get_param );

						}

					}

				} else {

					$get_param = WPBMap::getParam( $module, $param_id );

					if ( $get_param && is_array( $get_param ) ) {

						if ( is_array( $value ) ) {
							if ( 'dependency' == $key ) {
								$get_param[$key] = $value;
							} else {
								foreach ( $value as $sub_k => $sub_v ) {
									$get_param[$key][$sub_k] = $sub_v;
								}
							}
						} else {
							$get_param[$key] = $value;
						}

						vc_update_shortcode_param( $module, $get_param );

					}

				}

			}

		}

	}

}